/*
**  AREXX $VER: CreateOneMode 1.0 (13.05.94)
**
**  Georg Hessmann (hessmann@informatik.uni-hamburg.de)
**
**
**  CreateOneMode
**
**  Create the all fonts of one mode (defined via xdpi/ydpi and Modes file).
**
**
**  Arguments: xdpi ydpi pkdir
**
**    xdpi, ydpi : to select the mode (see MF:config/modes)
**    pkdir    : target directory
**
**  Test for all Magsteps, if there is a fontlist file in flistdir.
**  If so, call CreateMagBatch for this magstep. Than call
**  the created script file MagBatch.sh.
**  Repeat this for all magstps.
**
**
**
**  HISTORY:  
**
**  1.0:  Wrote the script.
**        Georg Hessmann (13.05.94)
**
*/

parse arg xdpi ydpi pkdir .

SIGNAL ON ERROR
SIGNAL ON FAILURE
SIGNAL ON BREAK_C
SIGNAL ON BREAK_D

flistdir  = "MF:config/fontlist"
CMagBatch = "MF:rexx/CreateMagBatch"
BatchFile = "RAM:MagBatch.sh"


Numeric DIGITS 12

MAGMULT.0      = 13            /* number of saved MagSteps */

MAGMULT.NUM.1  = 1.0           /* MagStep(0)   */
MAGMULT.STR.1  = "0"
MAGMULT.NUM.2  = 1.09544511501 /* MagStep(0.5) */
MAGMULT.STR.2  = "0.5"
MAGMULT.NUM.3  = 1.2           /* MagStep(1)   */
MAGMULT.STR.3  = "1"
MAGMULT.NUM.4  = 1.31453413801 /* MagStep(1.5) */
MAGMULT.STR.4  = "1.5"
MAGMULT.NUM.5  = 1.44          /* MagStep(2)   */
MAGMULT.STR.5  = "2"
MAGMULT.NUM.6  = 1.57744096561 /* MagStep(2.5) */
MAGMULT.STR.6  = "2.5"
MAGMULT.NUM.7  = 1.728         /* MagStep(3)   */
MAGMULT.STR.7  = "3"
MAGMULT.NUM.8  = 2.0736        /* MagStep(4)   */
MAGMULT.STR.8  = "4"
MAGMULT.NUM.9  = 2.48832       /* MagStep(5)   */
MAGMULT.STR.9  = "5"
MAGMULT.NUM.10 = 2.985984      /* MagStep(6)   */
MAGMULT.STR.10 = "6"
MAGMULT.NUM.11 = 3.5831808     /* MagStep(7)   */
MAGMULT.STR.11 = "7"
MAGMULT.NUM.12 = 4.29981696    /* MagStep(8)   */
MAGMULT.STR.12 = "8"
MAGMULT.NUM.13 = 5.159780352   /* MagStep(9)   */
MAGMULT.STR.13 = "9"


DO i=1 TO magmult.0
 
  flist = flistdir"/flst-"magmult.str.i
  IF exists(flist) THEN DO
    dpi = xdpi * magmult.num.i + 0.5
    dpi = dpi % 1
    
    pkdest = pkdir""dpi
    IF ~exists(pkdest) THEN address command 'makedir 'pkdest
    CMagBatch flist dpi xdpi ydpi pkdest"/"
    
    address command 'execute 'BatchFile
  END

END



EXIT 0

/*---------------------------------*/


BREAK_C:
BREAK_D:
ERROR:
FAILURE:
         EXIT 5
